.. module:: wwdtm.guest

*************
Module: guest
*************

This module provides objects used to retrieve guests, guest information and
guest details from a copy of the Wait Wait Don't Tell Me! Stats database.

.. contents:: Contents
    :depth: 1
    :local:
    :backlinks: none

Guest
=====

.. autoclass:: Guest
    :members:
    :inherited-members:

GuestAppearances
================

.. autoclass:: GuestAppearances
    :members:
    :inherited-members:

GuestUtility
============

.. autoclass:: GuestUtility
    :members:
    :inherited-members:
